caellion-python-commons: caellion.pycommons.codeanalysis Namespace Reference

caellion-python-commons

Namespaces
caellion.pycommons.codeanalysis Namespace Reference

This package provides facilities related to code analysis and reporting code analysis results. More...

## Namespaces
| reports
| This module provides utlilities related to creating Jenkins' warnings-ng-plugin-compatible reports from codeanalysis.

## Detailed Description

This package provides facilities related to code analysis and reporting code analysis results.